@@ -62,7 +62,7 @@ const char *const uih_colornames[] = {"white", "black", "red", NULL};
  * Zoltan Kovacs <kovzol@math.u-szeged.hu>, 2003-01-05
  */
 
-#define MAX_MENUDIALOGS_I18N 100
+#define MAX_MENUDIALOGS_I18N 104
 #define Register(variable) variable = &menudialogs_i18n[no_menudialogs_i18n]
 static menudialog menudialogs_i18n[MAX_MENUDIALOGS_I18N];
 // static int no_menudialogs_i18n;
@@ -76,7 +76,7 @@ static menudialog *uih_perturbationdialog, *uih_juliadialog,
     *uih_filterdialog, *uih_shiftdialog, *uih_speeddialog, *printdialog,
     *uih_bailoutdialog, *uih_threaddialog, *saveanimdialog, *uih_juliamodedialog,
     *uih_textposdialog, *uih_fastmodedialog, *uih_timedialog, *uih_numdialog,
-    *uih_fpdialog, *palettedialog, *uih_cyclingdialog
+    *uih_fpdialog, *palettedialog, *uih_cyclingdialog, *loadimgdialog, *palettegradientdialog
 #ifdef USE_SFFE
     ,
     *uih_sffedialog, *uih_sffeinitdialog
@@ -172,6 +172,10 @@ void uih_registermenudialogs_i18n(void)
     DIALOGIFILE_I(TR("Dialog", "Filename:"), "anim*.xaf");
     NULL_I();
 
+    Register(loadimgdialog);
+    DIALOGIFILE_I(TR("Dialog", "Filename:"), "fract*.png");
+    NULL_I();
+
     Register(saveimgdialog);
     DIALOGOFILE_I(TR("Dialog", "Filename:"), "fract*.png");
     NULL_I();
@@ -267,6 +271,10 @@ void uih_registermenudialogs_i18n(void)
     DIALOGINT_I(TR("Dialog", "Shift:"), 0);
     NULL_I();
 
+    Register(palettegradientdialog);
+    DIALOGPALSLIDER_I("Visualiser:", 0);
+    NULL_I();
+
     Register(uih_cyclingdialog);
     DIALOGINT_I(TR("Dialog", "Frames per second:"), 0);
     NULL_I();
@@ -557,6 +565,14 @@ static menudialog *uih_getpalettedialog(struct uih_context *uih)
     return (palettedialog);
 }
 
+static menudialog *uih_getpalettegradientdialog(struct uih_context *uih)
+{
+    if (uih != NULL) {
+        palettegradientdialog[0].defint = 0;
+    }
+    return (palettegradientdialog);
+}
+
 static menudialog *uih_getcyclingdialog(struct uih_context *uih)
 {
     if (uih != NULL)
@@ -586,6 +602,36 @@ static void uih_palette(struct uih_context *uih, dialogparam *p)
     int n1 = p[0].dint;
     int n2 = p[1].dint;
     int shift = p[2].dint;
+
+    if (!n1) {
+        uih_playdefpalette(uih, shift);
+        return;
+    }
+    if (n1 < 1 || n1 > PALGORITHMS) {
+        uih_error(uih, TR("Error", "Unknown palette type"));
+    }
+    if (uih->zengine->fractalc->palette == NULL)
+        return;
+    if (mkpalette(uih->zengine->fractalc->palette, n2, n1 - 1) != 0) {
+        uih_newimage(uih);
+    }
+    uih->manualpaletteshift = 0;
+    uih->palettetype = n1;
+    uih->palettechanged = 1;
+    uih->paletteseed = n2;
+    if (shiftpalette(uih->zengine->fractalc->palette, shift)) {
+        uih_newimage(uih);
+    }
+    uih->paletteshift = shift;
+}
+
+static void uih_palettegradient(struct uih_context *uih, dialogparam *p)
+{
+    fflush(stdout);
+    int n1 = uih->palettetype;
+    int n2 = uih->paletteseed;
+    int shift = uih->paletteshift;
+
     if (!n1) {
         uih_playdefpalette(uih, shift);
         return;
@@ -905,6 +951,8 @@ void uih_registermenus_i18n(void)
 
     MENUNOPCB_I("ui", "l", TR("Menu", "Ministatus"), "ministatus",
                 MENUFLAG_INCALC, uih_ministatus, uih_ministatusenabled);
+    MENUNOPCB_I("ui", "g", TR("Menu", "Cartesian Grid"), "cartesiangrid",
+                MENUFLAG_INCALC, uih_cartesiangrid, uih_cartesiangridenabled);
     MENUSEPARATOR_I("ui");
     MENUSEPARATOR_I("uia");
     MENUNOPCB_I("uia", "/", TR("Menu", "Status"), "animstatus",
@@ -913,6 +961,8 @@ void uih_registermenus_i18n(void)
 
     MENUNOPCB_I("uia", "l", TR("Menu", "Ministatus"), "animministatus",
                 UI | MENUFLAG_INCALC, uih_ministatus, uih_ministatusenabled);
+    MENUNOPCB_I("uia", "g", TR("Menu", "Cartesian Grid"), "animcartesiangrid",
+                MENUFLAG_INCALC, uih_cartesiangrid, uih_cartesiangridenabled);
     MENUSEPARATOR_I("uia");
     SUBMENU_I("root", "s", TR("Menu", "File"), "file");
     SUBMENU_I("root", NULL, TR("Menu", "Edit"), "edit");
@@ -983,6 +1033,8 @@ void uih_registermenus_i18n(void)
                  MENUFLAG_INTERRUPT | MENUFLAG_NOPLAY, uih_playfile,
                  playdialog);
     MENUSEPARATOR_I("file");
+    MENUDIALOG_I("file", NULL, TR("Menu", "Open image"), "loadimg",
+                MENUFLAG_INTERRUPT, uih_loadpngfile, loadimgdialog);
     MENUDIALOG_I("file", NULL, TR("Menu", "Save image"), "saveimg", 0,
                  uih_savepngfile, saveimgdialog);
     MENUDIALOG_I("file", NULL, TR("Menu", "Render"), "renderanim", UI,
@@ -1058,8 +1110,10 @@ void uih_registermenus_i18n(void)
               0, uih_mkdefaultpalette);
     MENUNOP_I("palettemenu", "p", TR("Menu", "Random palette"), "randompalette",
               0, uih_menumkpalette);
-    MENUCDIALOG_I("palettemenu", NULL, TR("Menu", "Custom palette"), "palette",
-                  0, uih_palette, uih_getpalettedialog);
+    MENUCDIALOG_I("", NULL, TR("Menu", "Custom palette"), "palette",
+                  0, uih_palette, uih_getpalettedialog); //This is a placeholder menu
+    MENUCDIALOG_I("palettemenu", NULL, TR("Menu", "Custom palette"), "palettegradient",
+                  0, uih_palettegradient, uih_getpalettegradientdialog);
     MENUSEPARATOR_I("palettemenu");
     MENUNOPCB_I("palettemenu", "y", TR("Menu", "Color cycling"), "cycling", 0,
                 uih_cyclingsw, uih_cyclingselected);
