@@ -23,7 +23,7 @@ static int first;
 static int changed;
 static int last;
 const char *const save_fastmode[] = {"zero", "never",   "animation",
-                                     "new",  "allways", NULL};
+                                     "new",  "always", NULL};
 
 const char *const xtextposnames[] = {"left", "center", "right", NULL};
 const char *const ytextposnames[] = {"top", "middle", "bottom", NULL};
@@ -611,7 +611,7 @@ int uih_save_enable(struct uih_context *uih, xio_file f, int mode)
         myputs(";Position file automatically generated by XaoS " XaoS_VERSION
                "\n"
                ";  - a realtime interactive fractal zoomer\n"
-               ";Use xaos -load <filename> to display it\n");
+               ";Use xaos -loadpos <filename> to display it\n");
     uih_saveframe(uih);
     uih_updatemenus(uih, "save");
     xio_putc('\n', f);
