@@ -102,11 +102,12 @@ int ui_params_parser(int argc, char **argv)
     int is;
     const struct params *par = NULL;
     int error = 0;
+    int show_help = 0;
     int found;
     for (i = 1; i < argc && !error; i++) {
         found = 0;
         if (!strcmp("-help", argv[i])) {
-            error = 1;
+            show_help = 1;
             break;
         }
         for (d = 0; d < nparams; d++) {
@@ -182,8 +183,11 @@ int ui_params_parser(int argc, char **argv)
             i = ie;
     }
     if (error) {
+        return 0;
+    }
+    if (show_help) {
         const char *name[] = {"", "number", "string", "f.point"};
-        printf("                 XaoS" XaoS_VERSION " help text\n\n");
+        printf("                 XaoS " XaoS_VERSION " help text\n\n");
         printf("option string   param   description\n\n");
         for (d = 0; d < nparams; d++) {
             par = params[d];
@@ -385,6 +389,7 @@ static void ui_unregistermenus(void)
 }
 
 QTranslator qtTranslator;
+QTranslator qtBaseTranslator;
 QTranslator xaosTranslator;
 char languageSetting[6] = "";
 bool languageSysDefault = true;
@@ -432,7 +437,11 @@ void setLanguage(const char *lang) {
     qtTranslator.load("qt_" + language,
                       QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     qApp->installTranslator(&qtTranslator);
-    xaosTranslator.load("XaoS_" + language, ":/i18n");
+    qtBaseTranslator.load(QLocale::system(),
+                          QStringLiteral("qtbase_"));
+    qApp->installTranslator(&qtBaseTranslator);
+    xaosTranslator.load("XaoS_" + language,
+                        ":/i18n");
     qApp->installTranslator(&xaosTranslator);
 
     /* Without this some locales (e.g. the Hungarian) replaces "." to ","
