@@ -357,6 +357,7 @@ void menu_activate(const menuitem *item, struct uih_context *c, dialogparam *d)
                      *parameter. This avoids need to write wrappers*/
                     switch (di[0].type) {
                         case DIALOG_INT:
+                        case DIALOG_PALSLIDER:
                         case DIALOG_CHOICE:
                         case DIALOG_ONOFF:
                             ((void (*)(struct uih_context * c, int))
@@ -720,7 +721,7 @@ int menu_processargs(int n, int argc, char **argv)
     margv = argv;
     error = menu_processcommand(NULL, gettoken, 0, MENUFLAG_NOOPTION, "root");
     if (error) {
-        x_error("%s", error);
+        x_error("%s\nPlease enter `xaos -help` to learn more on command line options", error);
         return -1;
     }
     return (argpos - 2);
